pub struct Arguments<E: StructOpt> {
pub draft: bool,
pub rest: E,
}Fields
draft: boolrest: ETrait Implementations
Sourceimpl<E> StructOpt for Arguments<E>where
E: StructOptInternal + StructOpt,
impl<E> StructOpt for Arguments<E>where
E: StructOptInternal + StructOpt,
Sourcefn from_clap(matches: &ArgMatches<'_>) -> Self
fn from_clap(matches: &ArgMatches<'_>) -> Self
Builds the struct from
clap::ArgMatches. It’s guaranteed to succeed
if matches originates from an App generated by StructOpt::clap called on
the same type, otherwise it must panic.Sourcefn from_args() -> Selfwhere
Self: Sized,
fn from_args() -> Selfwhere
Self: Sized,
Builds the struct from the command line arguments (
std::env::args_os).
Calls clap::Error::exit on failure, printing the error message and aborting the program.Sourcefn from_args_safe() -> Result<Self, Error>where
Self: Sized,
fn from_args_safe() -> Result<Self, Error>where
Self: Sized,
Builds the struct from the command line arguments (
std::env::args_os).
Unlike StructOpt::from_args, returns clap::Error on failure instead of aborting the program,
so calling .exit is up to you.Sourcefn from_iter<I>(iter: I) -> Self
fn from_iter<I>(iter: I) -> Self
Gets the struct from any iterator such as a
Vec of your making.
Print the error message and quit the program in case of failure. Read moreAuto Trait Implementations
impl<E> Freeze for Arguments<E>where
E: Freeze,
impl<E> RefUnwindSafe for Arguments<E>where
E: RefUnwindSafe,
impl<E> Send for Arguments<E>where
E: Send,
impl<E> Sync for Arguments<E>where
E: Sync,
impl<E> Unpin for Arguments<E>where
E: Unpin,
impl<E> UnwindSafe for Arguments<E>where
E: UnwindSafe,